#!/bin/bash
# IBM Confidential
# OCO Source Materials
# 5724-V51
#
# (c) Copyright IBM Corp. 2000, 2008 All Rights Reserved.
#
# The source code for this program is not published or otherwise
# divested of its trade secrets, irrespective of what has been
# deposited with the U.S. Copyright Office.

# This is the main driver script for Diagnostic Tools
# It mostly interpret command line options, and redirect to corresponding
# sub-scripts for the actual processing.
#
# To see the usage information: 
# pimSupport.sh --help 
#                    

if [ "X${TOP}" == "X" ]; then
    export TOP=$1
    echo "Setting TOP to $TOP"
    # source $TOP/bin/diagnostic/env_setup.rc
    . $TOP/bin/diagnostic/env_setup.rc 2>&1 > /dev/null
fi

. ${TOP}/bin/get_params.sh

if [ $# == 0 ]; then
    cat $TOP/bin/diagnostic/pim_support/pimSupport.version
    echo ""
    echo "For script usage, type: pimSupport.sh --help" 
    echo ""
    exit 0
fi

for _VAR in "$@"; do
    case ${_VAR} in
        --help)
        cat $TOP/bin/diagnostic/pim_support/pimSupport.usage
        exit
    esac
done

# For option: monitor=[start|stop], we need to move from pimSupport_localized.sh to here
# because pimSupport_localized.sh is executed within a Java process, and it has problems 
# returning from background job.
#
# start background system monitoring
if [ "X${_CCD_MONITOR}" != "X" ]; then

    if [ "$_CCD_MONITOR" = "start" ]; then
        ${ECHO} Starting system status monitor in background
        STATUS_DIR=$TOP/logs/diagnostic/system_status
        mkdir -p $STATUS_DIR

        $TOP/bin/diagnostic/common/startMonitor.sh &

        echo $! > $STATUS_DIR/monitor.pid 
	${ECHO} Saved background PID=`cat $STATUS_DIR/monitor.pid` 

        exit 0
    fi
    if [ "$_CCD_MONITOR" = "stop" ]; then
        ${ECHO} Stopping the background system status monitor

        $TOP/bin/diagnostic/common/stopMonitor.sh 
        exit 0
    fi

    echo "Option usage: --monitor=[start|stop]"
    exit 1
fi

if [ "X${_CCD_INTEGRITY}" != "X" ]; then
        echo "[pimSupport.sh] command line: $@"

	# we have to pass along the catalog/colarea name with space in it, such as "Product Catalog"
	# encoded it using ~ to replace the space
	if [ "X${_CCD_CATALOG}" != "X" ]; then
		export OPT_CATALOG=`echo ${_CCD_CATALOG} | sed 's/ /~/g'`
	fi

	if [ "X${_CCD_COLAREA}" != "X" ]; then
		export OPT_COLAREA=`echo ${_CCD_COLAREA} | sed 's/ /~/g'`
	fi

        $TOP/bin/diagnostic/integrity_check/integrityCheck.sh $@

    exit 0
fi

$JAVA_RT com.ibm.ccd.common.db.LocalizedShellScriptRunner "${SHELL} pimSupport_localized.sh $*" "$TOP/bin"

exit 0
